@@ -2,5 +2,5 @@
 
 from . import cli
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli()
